"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _sideUtils = require("@seleniumhq/side-utils");

var _codeExportCsharpCommons = require("@seleniumhq/code-export-csharp-commons");

function _objectSpread2(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

const emitters = _objectSpread2({}, _codeExportCsharpCommons.Command.emitters);

_sideUtils.codeExport.register.preprocessors(emitters);

function register(command, emitter) {
  _sideUtils.codeExport.register.emitter({
    command,
    emitter,
    emitters: emitters
  });
}

function emit(command) {
  return _sideUtils.codeExport.emit.command(command, emitters[command.command], {
    variableLookup: _codeExportCsharpCommons.Command.variableLookup,
    emitNewWindowHandling: _codeExportCsharpCommons.Command.extras.emitNewWindowHandling
  });
}

function canEmit(commandName) {
  return !!emitters[commandName];
}

emitters.assert = emitAssert;
emitters.verify = emitAssert;

function emitAssert(varName, value) {
  return Promise.resolve(`Assert.Equal(vars["${varName}"].ToString(), "${value}");`);
}

emitters.assertAlert = emitAssertAlert;
emitters.assertConfirmation = emitAssertAlert;
emitters.assertPrompt = emitAssertAlert;

function emitAssertAlert(AlertText) {
  return Promise.resolve(`Assert.Equal(driver.SwitchTo().Alert().Text, "${AlertText}");`);
}

emitters.assertChecked = emitVerifyChecked;
emitters.verifyChecked = emitVerifyChecked;

async function emitVerifyChecked(locator) {
  return Promise.resolve(`Assert.True(driver.FindElement(${await _codeExportCsharpCommons.location.emit(locator)}).Selected);`);
}

emitters.assertEditable = emitVerifyEditable;
emitters.verifyEditable = emitVerifyEditable;

async function emitVerifyEditable(locator) {
  const commands = [{
    level: 0,
    statement: '{'
  }, {
    level: 1,
    statement: `var element = driver.FindElement(${await _codeExportCsharpCommons.location.emit(locator)});`
  }, {
    level: 1,
    statement: 'Boolean isEditable = element.Enabled && element.GetAttribute("readonly") == null;'
  }, {
    level: 1,
    statement: 'Assert.True(isEditable);'
  }, {
    level: 0,
    statement: '}'
  }];
  return Promise.resolve({
    commands
  });
}

emitters.assertElementPresent = emitVerifyElementPresent;
emitters.verifyElementPresent = emitVerifyElementPresent;

async function emitVerifyElementPresent(locator) {
  const commands = [{
    level: 0,
    statement: '{'
  }, {
    level: 1,
    statement: `IReadOnlyCollection<IWebElement> elements = driver.FindElements(${await _codeExportCsharpCommons.location.emit(locator)});`
  }, {
    level: 1,
    statement: 'Assert.True(elements.Count > 0);'
  }, {
    level: 0,
    statement: '}'
  }];
  return Promise.resolve({
    commands
  });
}

emitters.assertElementNotPresent = emitVerifyElementNotPresent;
emitters.verifyElementNotPresent = emitVerifyElementNotPresent;

async function emitVerifyElementNotPresent(locator) {
  const commands = [{
    level: 0,
    statement: '{'
  }, {
    level: 1,
    statement: `IReadOnlyCollection<IWebElement> elements = driver.FindElements(${await _codeExportCsharpCommons.location.emit(locator)});`
  }, {
    level: 1,
    statement: 'Assert.True(elements.Count == 0);'
  }, {
    level: 0,
    statement: '}'
  }];
  return Promise.resolve({
    commands
  });
}

emitters.assertNotChecked = emitVerifyNotChecked;
emitters.verifyNotChecked = emitVerifyNotChecked;

async function emitVerifyNotChecked(locator) {
  return Promise.resolve(`Assert.False(driver.FindElement(${await _codeExportCsharpCommons.location.emit(locator)}).Selected);`);
}

emitters.assertNotEditable = emitVerifyNotEditable;
emitters.verifyNotEdtiable = emitVerifyNotEditable;

async function emitVerifyNotEditable(locator) {
  const commands = [{
    level: 0,
    statement: '{'
  }, {
    level: 1,
    statement: `var element = driver.FindElement(${await _codeExportCsharpCommons.location.emit(locator)});`
  }, {
    level: 1,
    statement: 'Boolean isEditable = element.Enabled && element.GetAttribute("readonly") == null;'
  }, {
    level: 1,
    statement: 'Assert.False(isEditable);'
  }, {
    level: 0,
    statement: '}'
  }];
  return Promise.resolve({
    commands
  });
}

emitters.assertNotSelectedValue = emitVerifyNotSelectedValue;
emitters.verifyNotSelectedValue = emitVerifyNotSelectedValue;

async function emitVerifyNotSelectedValue(locator, expectedValue) {
  const commands = [{
    level: 0,
    statement: '{'
  }, {
    level: 1,
    statement: `String value = driver.FindElement(${await _codeExportCsharpCommons.location.emit(locator)}).GetAttribute("value");`
  }, {
    level: 1,
    statement: `Assert.NotEqual(value, ${_sideUtils.codeExport.emit.text(expectedValue)});`
  }, {
    level: 0,
    statement: '}'
  }];
  return Promise.resolve({
    commands
  });
}

emitters.assertNotText = emitVerifyNotText;
emitters.verifyNotText = emitVerifyNotText;

async function emitVerifyNotText(locator, text) {
  const result = `driver.FindElement(${await _codeExportCsharpCommons.location.emit(locator)}).Text`;
  return Promise.resolve(`Assert.NotEqual(${result}, "${_sideUtils.codeExport.emit.text(text)}");`);
}

emitters.assertSelectedLabel = emitVerifySelectedLabel;
emitters.verifySelectedLabel = emitVerifySelectedLabel;

async function emitVerifySelectedLabel(locator, labelValue) {
  const commands = [{
    level: 0,
    statement: '{'
  }, {
    level: 1,
    statement: `var element = driver.FindElement(${await _codeExportCsharpCommons.location.emit(locator)});`
  }, {
    level: 1,
    statement: 'String value = element.GetAttribute("value");'
  }, {
    level: 1,
    statement: `String locator = String.Format("option[@value='%s']", "value");`
  }, {
    level: 1,
    statement: 'String selectedText = element.FindElement(By.XPath(locator)).Text;'
  }, {
    level: 1,
    statement: `Assert.Equal(selectedText, "${labelValue}");`
  }, {
    level: 0,
    statement: '}'
  }];
  return Promise.resolve({
    commands
  });
}

emitters.assertSelectedValue = emitVerifyValue;
emitters.verifySelectedValue = emitVerifyValue;
emitters.assertValue = emitVerifyValue;

async function emitVerifyValue(locator, value) {
  const commands = [{
    level: 0,
    statement: '{'
  }, {
    level: 1,
    statement: `String value = driver.FindElement(${await _codeExportCsharpCommons.location.emit(locator)}).GetAttribute("value");`
  }, {
    level: 1,
    statement: `Assert.Equal(value, "${value}");`
  }, {
    level: 0,
    statement: '}'
  }];
  return Promise.resolve({
    commands
  });
}

emitters.assertText = emitVerifyText;
emitters.verifyText = emitVerifyText;

async function emitVerifyText(locator, text) {
  return Promise.resolve(`Assert.Equal(driver.FindElement(${await _codeExportCsharpCommons.location.emit(locator)}).Text, "${_sideUtils.codeExport.emit.text(text)}");`);
}

emitters.assertTitle = emitVerifyTitle;
emitters.verifyTitle = emitVerifyTitle;

async function emitVerifyTitle(title) {
  return Promise.resolve(`Assert.Equal(driver.Title, "${title}");`);
}

var _default = {
  canEmit,
  emit,
  register,
  extras: {
    emitWaitForWindow: _codeExportCsharpCommons.Command.extras.emitWaitForWindow
  }
};
exports.default = _default;